@@ -163,6 +163,7 @@ describe RHC::Commands::App do
       let!(:config){ base_config }
       before{ RHC::Config.any_instance.stub(:has_local_config?).and_return(false) }
       before{ described_class.any_instance.stub(:interactive?).and_return(true) }
+      before{ described_class.any_instance.stub(:discover_git_executable).and_return('git') }
       before{ rest_client.domains.clear }
       before{ rest_client.sshkeys.delete_if {|k| !k.is_ssh? } }
       let(:arguments) { ['app', 'create', 'app1', 'mock_standalone_cart-1'] }
@@ -406,6 +407,7 @@ describe RHC::Commands::App do
       @domain = rest_client.add_domain("mockdomain")
       @instance.stub(:git_clone_application) { raise RHC::GitException }
       @instance.stub(:check_sshkeys!)
+      @instance.stub(:discover_git_executable).and_return('git')
     end
 
     context 'when run with error in git clone' do
@@ -428,6 +430,7 @@ describe RHC::Commands::App do
         RHC::Helpers.stub(:windows?) { true }
         @instance.stub(:run_nslookup) { true }
         @instance.stub(:run_ping) { true }
+        @instance.stub(:has_git?) { true }
       end
       it "should print out git warning" do
         run_output.should match(" We were unable to clone your application's git repo")
@@ -439,6 +442,7 @@ describe RHC::Commands::App do
         RHC::Helpers.stub(:windows?) { true }
         @instance.stub(:run_nslookup) { true }
         @instance.stub(:run_ping) { false }
+        @instance.stub(:has_git?) { true }
       end
       it "should print out windows warning" do
         run_output.should match("This may also be related to an issue with Winsock on Windows")
@@ -473,26 +477,66 @@ describe RHC::Commands::App do
     before(:each) do
       FakeFS.deactivate!
       @domain = rest_client.add_domain("mockdomain")
-      @app = @domain.add_application("app1", "mock_standalone_cart-1")
+      @app = @domain.add_application("app1", :cartridge=>"mock_standalone_cart-1")
       @app.add_alias('myfoo.com')
       @cart1 = @app.add_cartridge('mock_cart-1')
       @cart2 = @app.add_cartridge('mock_cart-2')
       @cart2.gear_profile = 'medium'
       @instance.stub(:save_snapshot)
       @instance.stub(:restore_snapshot)
+      @app.stub(:region){'aRegion'}
+      rest_client.api.stub(:supports?).with(:LIST_REGIONS){true} 
     end
 
-    context 'when run' do
+    context 'when run and the broker allows region selection' do
+      before do
+        rest_client.stub(:regions) do
+          region = double()
+          region.stub(:allow_selection){true}
+          [region]
+        end
+      end
+
       let(:arguments) { ['app', 'create', 'clone', '--from-app', 'app1', '--no-git'] }
       it { expect { run }.to exit_with_code(0) }
       it "should clone successfully" do
         run_output.should match(/Cartridges:\s+mock_standalone_cart-1, mock_cart-1, mock_cart-2/)
         run_output.should match(/Gear Size:\s+Copied from 'app1'/)
         run_output.should match(/Setting deployment configuration/)
+        run_output.should match(/Region:\s+aRegion\s+\(copied from 'app1'/)
         run_output.should match(/done/)
       end
     end
 
+    context 'when source app has a region and the broker does not allow region selection' do
+
+      context 'and region flag is not specified' do
+        let(:arguments) { ['app', 'create', 'app2', '--from-app', 'app1', '--no-git'] }
+        it "should clone successfully" do
+          expect { run }.to exit_with_code(0)
+          run_output.should match(/Server does not allow selecting regions.  Region is being ignored./)
+          run_output.should match(/Cartridges:\s+mock_standalone_cart-1, mock_cart-1, mock_cart-2/)
+          run_output.should match(/Gear Size:\s+Copied from 'app1'/)
+          run_output.should_not match(/Region:\s+aRegion\s+\(copied from 'app1'/)
+          run_output.should match(/Setting deployment configuration/)
+          run_output.should match(/done/)
+        end
+      end
+
+      context 'and region flag is specified' do
+        let(:arguments) { ['app', 'create', 'app2', '--from-app', 'app1', '--region','foo','--no-git'] }
+        it "should clone successfully" do
+          run_output.should match(/Server does not allow selecting regions.  Region is being ignored./)
+          run_output.should match(/Cartridges:\s+mock_standalone_cart-1, mock_cart-1, mock_cart-2/)
+          run_output.should match(/Gear Size:\s+Copied from 'app1'/)
+          run_output.should_not match(/Region:\s+aRegion\s+\(copied from 'app1'/)
+          run_output.should match(/Setting deployment configuration/)
+          run_output.should match(/done/)
+          expect { run }.to exit_with_code(0)
+        end
+      end
+    end
+
     context 'when cloning a scalable app as not scalable' do
       before do
         @scaled = @domain.add_application("scaled", "mock_standalone_cart-1", true)
@@ -848,6 +892,29 @@ describe RHC::Commands::App do
       it { run_output.should match('cleaned') }
       it { expect{ run }.to exit_with_code(0) }
     end
+
+    context 'app enable-ha' do
+      let(:arguments) { ['app', 'enable-ha', 'app1'] }
+      it { run_output.should match('is now highly available') }
+      it { expect{ run }.to exit_with_code(0) }
+    end
+
+  end
+
+  describe 'app enable-ha' do
+    before do
+      @domain = rest_client.add_domain("mockdomain")
+      @app = @domain.add_application("app1", "mock_type")
+      @app.add_cartridge('mock_cart-1')
+      @app.links.delete 'MAKE_HA'
+    end
+
+    let(:arguments) { ['app', 'enable-ha', 'app1'] }
+
+    it "should raise ha not supported exception" do
+      run_output.should match(/The server does not support high availability/)
+      expect{ run }.to exit_with_code(135)
+    end
   end
 
   describe "#create_app" do
